**Example 1: 删除集群**

指定集群ID删除TcaplusDB集群。

Input: 

```
tccli tcaplusdb DeleteCluster --cli-unfold-argument  \
    --ClusterId 6179109757
```

Output: 
```
{
    "Response": {
        "RequestId": "abd7111a-62d4-4bbb-a781-3646040e9530",
        "TaskId": "6179109757-1210"
    }
}
```

